summaryrefslogtreecommitdiff
path: root/src/dcp.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2018-09-25 09:41:32 +0100
committerCarl Hetherington <cth@carlh.net>2018-09-25 09:41:32 +0100
commit6ff5bc54fafcb9332609912514c287ac332ab7e5 (patch)
treef1458b2735af96eaa4352601762337c2e1812ef4 /src/dcp.h
parentdf56c3975454d935b8457d8a8bc1615388db305c (diff)
Cope with multiple PKLs in a DCP.
Diffstat (limited to 'src/dcp.h')
-rw-r--r--src/dcp.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/dcp.h b/src/dcp.h
index 9c97e6aa..b47daf55 100644
--- a/src/dcp.h
+++ b/src/dcp.h
@@ -129,11 +129,11 @@ public:
return _directory;
}
/** @return PKL if this DCP was read from an existing one, or if write_xml() has been called on it.
* If neither is true, this method returns 0.
*/
- boost::shared_ptr<PKL> pkl () const {
- return _pkl;
+ std::list<boost::shared_ptr<PKL> > pkls () const {
+ return _pkls;
}
static std::vector<boost::filesystem::path> directories_from_files (std::vector<boost::filesystem::path> files);
@@ -152,7 +152,7 @@ private:
boost::filesystem::path _directory;
/** the CPLs that make up this DCP */
std::list<boost::shared_ptr<CPL> > _cpls;
- boost::shared_ptr<PKL> _pkl;
+ std::list<boost::shared_ptr<PKL> > _pkls;
/** Standard of DCP that was read in */
boost::optional<Standard> _standard;
@@ -129,11 +129,11 @@ public:
return _directory;
}
- /** @return PKL if this DCP was read from an existing one, or if write_xml() has been called on it.
- * If neither is true, this method returns 0.
+ /** @return PKLs if this DCP was read from an existing one, or if write_xml() has been called on it.
+ * If neither is true, this method returns an empty list.
*/